spotify

package module
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2021 License: OSL-3.0 Imports: 17 Imported by: 0

README

Spotify

This module works with Spotify free accounts. It can download individual tracks. It downloads the audio files served by Spotify's servers and does not work by recording audio outputs.

https://godocs.io/github.com/89z/spotify

HTTPS

audio-fa.scdn.co/audio

We're using HTTPS-based CDN audio file retrieval, similar to the official Web client or librespot-java, instead of the older, channel-based approach in librespot.

https://github.com/jpochyla/psst#thanks

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Session added in v1.0.1

type Session struct {
	// contains filtered or unexported fields
}

func Login

func Login(username string, password string, deviceName string) (*Session, error)

func (*Session) DownloadTrackID added in v1.0.1

func (s *Session) DownloadTrackID(id string) (io.Reader, error)

Jump to